 /*
 * file      : src/winexport.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */



#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>
#include <cairo.h>
#include <cairo-pdf.h>
#include <cairo-ps.h>
#include <cairo-xlib.h>
#include <X11/Xlib.h>
#include <string.h>
#include <stdlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "configuser.h"
#include "fileselect.h"
#include "win_export.h"



typedef struct {

	GtkWidget	*AdrWin;			// Adresse de la fenetre
	gboolean	IsShow;				// TRUE or FALSE
	GtkWidget	*AdrButtonExportPathnamefile;	// Adresse button export
	GtkWidget	*AdrCheckbuttonPDF;		// 
	GtkWidget	*AdrCheckbuttonPNG;		// 
	GtkWidget	*AdrCheckbuttonPS;		// 
	GtkWidget	*AdrCheckbuttonTXT;		// 
	void		(*FuncExtern)( void );		// 
	
} VAR_WIN_EXPORT;

VAR_WIN_EXPORT VarWinExport = { 
	
	NULL,
	FALSE,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL
	
	};





// 
// 
gboolean on_window_export_destroy_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	return( TRUE );
}
// 
// 
gboolean on_window_export_delete_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	return( TRUE );
}
// 
// 
void WinExport_select( gchar *p_path )
{
	// TESTS SUR:
	// pdf
	// png
	// ps
	// txt
	
	g_print( "p_path = %s\n", p_path );

	g_free( Config.PathNameFileExport );
	Config.PathNameFileExport = NULL;
	Config.PathNameFileExport = g_strdup( p_path );
	gtk_button_set_label( GTK_BUTTON(VarWinExport.AdrButtonExportPathnamefile), Config.PathNameFileExport );

}
// 
// 
void on_button_export_pathnamefile_clicked( GtkButton *button, gpointer user_data )
{
	fileselect( _("Choix d'un nom de fichier pour l'exportation"), GTK_FILE_CHOOSER_ACTION_SAVE,  WinExport_select, Config.PathNameFileExport, VarWinExport.AdrWin );
}
void on_button_export_cancel_clicked( GtkButton *button, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
}
// 
// 
void on_button_export_pathnamefile_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrButtonExportPathnamefile = widget;
	
	// SI PAS DE NOM DE FICHIER : AJOUTER
	if( TRUE == libutils_test_dir_exist( Config.PathNameFileExport )) {
		
		gchar *Dummy = g_strdup( Config.PathNameFileExport );
		
		g_free( Config.PathNameFileExport );
		Config.PathNameFileExport = NULL;
		Config.PathNameFileExport = g_strdup_printf( "%s/export", Dummy );
		g_free( Dummy );
		Dummy = NULL;
	}
	gtk_button_set_label( GTK_BUTTON(VarWinExport.AdrButtonExportPathnamefile), Config.PathNameFileExport );
}
// 
// 
void WinExport_set_sensitive_button_apply( void )
{
	gboolean	BoolCheckButton;
	
	BoolCheckButton = Config.BoolExportPdf || Config.BoolExportPng || Config.BoolExportPs || Config.BoolExportTxt;
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_export_apply")), BoolCheckButton );
}
void on_checkbutton_format_clicked( GtkButton *button, gpointer user_data )
{
	if( NULL != VarWinExport.AdrCheckbuttonPDF && GTK_BUTTON(VarWinExport.AdrCheckbuttonPDF) == button ) {
		Config.BoolExportPdf = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(VarWinExport.AdrCheckbuttonPDF) );
	}
	else if( NULL != VarWinExport.AdrCheckbuttonPNG && GTK_BUTTON(VarWinExport.AdrCheckbuttonPNG) == button ) {
		Config.BoolExportPng = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(VarWinExport.AdrCheckbuttonPNG) );
	}
	else if( NULL != VarWinExport.AdrCheckbuttonPS && GTK_BUTTON(VarWinExport.AdrCheckbuttonPS) == button ) {
		Config.BoolExportPs  = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(VarWinExport.AdrCheckbuttonPS) );
	}
	else if( NULL != VarWinExport.AdrCheckbuttonTXT && GTK_BUTTON(VarWinExport.AdrCheckbuttonTXT) == button ) {
		Config.BoolExportTxt = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(VarWinExport.AdrCheckbuttonTXT) );
	}
	WinExport_set_sensitive_button_apply();
}
void on_checkbutton_format_pdf_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrCheckbuttonPDF = widget;
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolExportPdf );
	WinExport_set_sensitive_button_apply();
}
void on_checkbutton_format_png_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrCheckbuttonPNG = widget;
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolExportPng );
	WinExport_set_sensitive_button_apply();
}
void on_checkbutton_format_ps_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrCheckbuttonPS = widget;
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolExportPs );
	WinExport_set_sensitive_button_apply();
}
void on_checkbutton_format_txt_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrCheckbuttonTXT = widget;
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolExportTxt );
	WinExport_set_sensitive_button_apply();
}
// 
// 
void on_button_export_apply_clicked( GtkButton *button, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	
	// L'AFFICHAGE EST FAIT DEPUIS L'EXTERIEUR
	if( VarWinExport.FuncExtern ) (*VarWinExport.FuncExtern)();
}
// 
// 
void WinExport_open( void (*FuncExtern) ( void ) )
{
	VarWinExport.FuncExtern = FuncExtern;
	
	if( TRUE == VarWinExport.IsShow ) {
		gdk_window_raise( VarWinExport.AdrWin->window );
	}
	else {
		if( NULL == VarWinExport.AdrWin ) {
			VarWinExport.AdrWin = GTK_WIDGET(GLADE_GET_OBJECT("window_export"));
			gtk_builder_connect_signals( GtkBuilderProjet, NULL );
		}
		gtk_window_set_transient_for( GTK_WINDOW(VarWinExport.AdrWin), GTK_WINDOW(WindMain) );
		gtk_window_set_modal( GTK_WINDOW(VarWinExport.AdrWin), TRUE );
		libutils_set_default_icone_to_win( VarWinExport.AdrWin );
		gtk_window_set_title( GTK_WINDOW( VarWinExport.AdrWin ), "Time Management" );
		gtk_window_set_position( GTK_WINDOW(VarWinExport.AdrWin), GTK_WIN_POS_CENTER );
		VarWinExport.IsShow = TRUE;
		gtk_widget_show( VarWinExport.AdrWin );
	}
}


















